/*
 * merror.c
 * 
 * This file is part of the msmtp package, a very simple programm that 
 * works as an "SMTP plugin" for Mutt and possibly other MUAs.
 *
 * Copyright (C) 2000, 2003	Martin Lambers <marlam@users.sourceforge.net>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>
#include <sysexits.h>

#include "msmtp.h"
#include "list.h"
#include "xmalloc.h"


list_t *error_lines = NULL;
list_t *last_line = NULL;


/*
 * die()
 *
 * Print error message and exit with EX_OSERR.
 * To be used when memory allocation fails.
 */

void die(char *s)
{
    fprintf(stderr, "%s: %s\n%s: FATAL: not enough memory!\n", 
	    prgname, s, prgname);
    exit(EX_OSERR);
}


/*
 * add_error_line()
 *
 * Adds an error line to the list of error lines.
 * The string should not end with '\n', as this is automatically added when
 * printing the lines with print_error_lines().
 */

void add_error_line(char *format, ...)
{
    va_list args;
    char *tmp;

    if (!error_lines)
    {
	error_lines = list_new();
	last_line = error_lines;
    }

    va_start(args, format);
    xvasprintf(&tmp, format, args);
    va_end(args);
    
    list_insert(last_line, tmp);
    last_line = last_line->next;
}


/*
 * print_error_lines()
 *
 * Prints all error lines to 'f'. Oldest lines are printed first.
 * Deletes all error lines afterwards.
 */
void print_error_lines(FILE *f)
{
    list_t *p;
    
    if (error_lines)
    {
	p = error_lines->next;
	while (p->next != p)
	{
	    fprintf(f, "%s: %s\n", prgname, (char *)p->data);
	    p = p->next;
	}
	list_xfree(error_lines, free);
	error_lines = NULL;
	last_line = NULL;
    }
}
